package com.fs.company.service;

import java.util.List;
import com.fs.company.domain.CompanyProductStock;

/**
 * 产品库存Service接口
 * 
 * @author fs
 * @date 2025-07-01
 */
public interface ICompanyProductStockService 
{
    /**
     * 查询产品库存
     * 
     * @param id 产品库存主键
     * @return 产品库存
     */
    public CompanyProductStock selectCompanyProductStockById(Long id);

    /**
     * 查询产品库存列表
     * 
     * @param companyProductStock 产品库存
     * @return 产品库存集合
     */
    public List<CompanyProductStock> selectCompanyProductStockList(CompanyProductStock companyProductStock);

    /**
     * 新增产品库存
     * 
     * @param companyProductStock 产品库存
     * @return 结果
     */
    public int insertCompanyProductStock(CompanyProductStock companyProductStock);

    /**
     * 修改产品库存
     * 
     * @param companyProductStock 产品库存
     * @return 结果
     */
    public int updateCompanyProductStock(CompanyProductStock companyProductStock);

    /**
     * 批量删除产品库存
     * 
     * @param ids 需要删除的产品库存主键集合
     * @return 结果
     */
    public int deleteCompanyProductStockByIds(Long[] ids);

    /**
     * 删除产品库存信息
     * 
     * @param id 产品库存主键
     * @return 结果
     */
    public int deleteCompanyProductStockById(Long id);
}
